@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Moo;
 use Music::Chord::Note;
@@ -151,7 +151,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
@@ -176,7 +176,7 @@ version 0.0500
     format => 'midi',
   );
 
-  my $chords = $mc->cadence( type => 'perfect' );
+  $chords = $mc->cadence( type => 'perfect' );
   # [['Gs5','C5','Ds5'], ['Cs5','F5','Gs5']]
 
 =head1 DESCRIPTION
@@ -215,8 +215,8 @@ append."
 
 =head2 format
 
-If C<midi>, convert sharp C<#> to C<s> and C<b> to C<f> after chord
-generation.  Default: C<''> (none)
+If C<midi>, convert sharp C<#> to C<s> and flat C<b> to C<f> after
+chord generation.  Default: C<''> (none)
 
 =head1 METHODS
 
@@ -295,7 +295,7 @@ L<https://www.musictheoryacademy.com/how-to-read-sheet-music/cadences/>
 
 Evaded cadence
 
-Imperfect cadence
+Imperfect cadences
 
 =head1 AUTHOR
 
